@@ -156,8 +156,8 @@ static GnmFuncHelp const help_lcm[] = {
 	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
-	   "LCM(2,13) equals to 26.\n"
-	   "LCM(4,7,5) equals to 140.\n"
+	   "LCM(2,13) equals 26.\n"
+	   "LCM(4,7,5) equals 140.\n"
 	   "\n"
 	   "@SEEALSO=GCD")
 	},
@@ -210,7 +210,7 @@ static GnmFuncHelp const help_hypot[] = {
 	   "HYPOT returns the square root of the sum of the squares of the arguments.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
-	   "HYPOT(3,4) equals to 5.\n"
+	   "HYPOT(3,4) equals 5.\n"
 	   "\n"
 	   "@SEEALSO=MIN,MAX")
 	},
@@ -1223,7 +1223,7 @@ static GnmFuncHelp const help_power[] = {
 	   "@DESCRIPTION="
 	   "POWER returns the value of @x raised to the power @y.\n\n"
 	   "\n"
-	   "* If both @x and @y equals to 0, POWER returns #NUM! error.\n"
+	   "* If both @x and @y equal 0, POWER returns #NUM! error.\n"
 	   "* If @x = 0 and @y < 0, POWER returns #DIV/0! error.\n"
 	   "* If @x < 0 and @y is non-integer, POWER returns #NUM! error.\n"
 	   "* This function is Excel compatible.\n"
@@ -2911,8 +2911,8 @@ static GnmFuncHelp const help_minverse[] = {
 
 
 static GnmValue *
-callback_function_mmult_validate (Sheet *sheet, int col, int row,
-				  GnmCell *cell, void *user_data)
+cb_function_mmult_validate (Sheet *sheet, int col, int row,
+			     GnmCell *cell, void *user_data)
 {
         int *item_count = user_data;
 
@@ -2924,6 +2924,7 @@ callback_function_mmult_validate (Sheet *sheet, int col, int row,
 	return NULL;
 }
 
+/* Returns TRUE on error */
 static gboolean
 validate_range_numeric_matrix (GnmEvalPos const *ep, GnmValue const *matrix,
 			       int *rows, int *cols,
@@ -2935,13 +2936,12 @@ validate_range_numeric_matrix (GnmEvalPos const *ep, GnmValue const *matrix,
 	*cols = value_area_get_width (matrix, ep);
 	*rows = value_area_get_height (matrix, ep);
 
-	/* No checking needed for arrays */
-	if (matrix->type == VALUE_ARRAY)
-	    return FALSE;
-
-	if (matrix->v_range.cell.a.sheet != matrix->v_range.cell.b.sheet &&
-	    matrix->v_range.cell.a.sheet != NULL &&
-	    matrix->v_range.cell.b.sheet != NULL) {
+	if (matrix->type == VALUE_ARRAY || matrix->type <= VALUE_FLOAT)
+		return FALSE;
+	if (matrix->type != VALUE_CELLRANGE ||
+	    (matrix->v_range.cell.a.sheet != matrix->v_range.cell.b.sheet &&
+	     matrix->v_range.cell.a.sheet != NULL &&
+	     matrix->v_range.cell.b.sheet != NULL)) {
 		*err = GNM_ERROR_VALUE;
 		return TRUE;
 	}
@@ -2953,7 +2953,7 @@ validate_range_numeric_matrix (GnmEvalPos const *ep, GnmValue const *matrix,
 		matrix->v_range.cell.a.row,
 		matrix->v_range.cell.b.col,
 		matrix->v_range.cell.b.row,
-		callback_function_mmult_validate,
+		cb_function_mmult_validate,
 		&cell_count);
 
 	if (res != NULL || cell_count != (*rows * *cols)) {
@@ -3005,9 +3005,8 @@ gnumeric_minverse (FunctionEvalInfo *ei, GnmValue const * const *argv)
 	gnm_float **matrix;
 	GnmStdError err;
 
-	if (validate_range_numeric_matrix (ep, values, &rows, &cols, &err)) {
+	if (validate_range_numeric_matrix (ep, values, &rows, &cols, &err))
 		return value_new_error_std (ei->pos, err);
-	}
 
 	/* Guarantee shape and non-zero size */
 	if (cols != rows || !rows || !cols)
@@ -3065,12 +3064,9 @@ gnumeric_mmult (FunctionEvalInfo *ei, GnmValue const * const *argv)
 	gnm_float *A, *B, *product;
 	GnmStdError err;
 
-	if (validate_range_numeric_matrix (ep, values_a, &rows_a, &cols_a,
-					   &err) ||
-	    validate_range_numeric_matrix (ep, values_b, &rows_b, &cols_b,
-					   &err)) {
+	if (validate_range_numeric_matrix (ep, values_a, &rows_a, &cols_a, &err) ||
+	    validate_range_numeric_matrix (ep, values_b, &rows_b, &cols_b, &err))
 		return value_new_error_std (ei->pos, err);
-	}
 
 	/* Guarantee shape and non-zero size */
 	if (cols_a != rows_b || !rows_a || !rows_b || !cols_a || !cols_b)
@@ -3164,27 +3160,25 @@ gnumeric_mdeterm (FunctionEvalInfo *ei, GnmValue const * const *argv)
 /***************************************************************************/
 
 static GnmFuncHelp const help_sumproduct[] = {
-	{ GNM_FUNC_HELP_OLD,
-	F_("@FUNCTION=SUMPRODUCT\n"
-	   "@SYNTAX=SUMPRODUCT(range1,range2,...)\n"
-	   "@DESCRIPTION="
-	   "SUMPRODUCT function multiplies corresponding data entries in the "
-	   "given arrays or ranges, and then returns the sum of those "
-	   "products.  If an array entry is not numeric, the value zero is "
-	   "used instead.\n"
-	   "\n"
-	   "* If arrays or range arguments do not have the same dimensions, "
-	   "SUMPRODUCT returns #VALUE! error.\n"
-	   "* This function is Excel compatible.\n"
-	   "\n"
+	{ GNM_FUNC_HELP_NAME, F_("SUMPRODUCT:Multiplies components and adds the results.") },
+	{ GNM_FUNC_HELP_DESCRIPTION,
+		F_("Multiplies corresponding data entries in the "
+		   "given arrays or ranges, and then returns the sum of those "
+		   "products.") },
+	{ GNM_FUNC_HELP_NOTE, F_("If an entry is not numeric, the value zero is used instead.") },
+	{ GNM_FUNC_HELP_NOTE, F_("If arrays or range arguments do not have the same dimensions, "
+	   "return #VALUE! error.") },
+	{ GNM_FUNC_HELP_NOTE, F_("SUMPRODUCTs arguments are arrays or ranges. "
+				 "Attempting to use A1:A5>0 will not work, implicit intersection will kick in. "
+				 "Instead use --(A1:A5>0)") },
+#if 0
 	   "@EXAMPLES=\n"
 	   "Let us assume that the cells A1, A2, ..., A5 contain numbers "
 	   "11, 15, 17, 21, and 43 and the cells B1, B2, ..., B5 hold "
 	   "numbers 13, 22, 31, 33, and 39.  Then\n"
 	   "SUMPRODUCT(A1:A5,B1:B5) equals 3370.\n"
-	   "\n"
-	   "@SEEALSO=SUM,PRODUCT")
-	},
+#endif
+	{ GNM_FUNC_HELP_SEEALSO, "SUM,PRODUCT,G_PRODUCT" },
 	{ GNM_FUNC_HELP_END }
 };
 
