@@ -18,7 +18,6 @@
  */
 
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
 #include <gnumeric.h>
 #include <libgda/libgda.h>
 #ifdef HAVE_LIBGNOMEDB
@@ -27,14 +26,14 @@
 #endif
 
 #include "func.h"
-#include "plugin.h"
-#include "plugin-util.h"
-#include "error-info.h"
-#include "module-plugin-defs.h"
 #include "expr.h"
 #include "value.h"
+#include "gnm-i18n.h"
+#include <goffice/app/go-plugin.h>
+#include <goffice/app/error-info.h>
+#include <gnm-plugin.h>
 
-GNUMERIC_MODULE_PLUGIN_INFO_DECL;
+GNM_PLUGIN_MODULE_HEADER;
 
 static GdaClient* connection_pool = NULL;
 
@@ -88,6 +87,7 @@ open_connection (const gchar *dsn, const gchar *user, const gchar *password, Gda
 #ifdef HAVE_LIBGNOMEDB
 	GtkWidget *dialog, *login;
 #endif
+	GError *error = NULL;
 
 	/* initialize connection pool if first time */
 	if (!GDA_IS_CLIENT (connection_pool)) {
@@ -120,7 +120,11 @@ open_connection (const gchar *dsn, const gchar *user, const gchar *password, Gda
 	real_password = g_strdup (password);
 #endif
 
-	cnc = gda_client_open_connection (connection_pool, real_dsn, real_user, real_password, options);
+	cnc = gda_client_open_connection (connection_pool, real_dsn, real_user, real_password, options, &error);
+	if (!cnc) {
+		g_warning ("Libgda error: %s\n", error->message);
+		g_error_free (error);
+	}
 
 	g_free (real_dsn);
 	g_free (real_user);
@@ -132,8 +136,9 @@ open_connection (const gchar *dsn, const gchar *user, const gchar *password, Gda
 /*
  * execSQL function
  */
-static char const *help_execSQL = {
-	N_("@FUNCTION=EXECSQL\n"
+static GnmFuncHelp const help_execSQL[] = {
+    { GNM_FUNC_HELP_OLD,
+	F_("@FUNCTION=EXECSQL\n"
 	   "@SYNTAX=EXECSQL(dsn,username,password,sql)\n"
 	   "@DESCRIPTION="
 	   "The EXECSQL function lets you execute a command in a"
@@ -147,6 +152,8 @@ static char const *help_execSQL = {
 	   " in the \"mydatasource\" GDA data source, you would use:\n"
 	   "EXECSQL(\"mydatasource\",\"username\",\"password\",\"SELECT * FROM customers\")\n"
 	   "@SEEALSO=READDBTABLE")
+    },
+    { GNM_FUNC_HELP_END }
 };
 
 static GnmValue *
@@ -161,6 +168,7 @@ gnumeric_execSQL (FunctionEvalInfo *ei, GnmValue **args)
 	GdaDataModel*  recset;
 	GList*         recset_list;
 	GdaCommand*    cmd;
+	GError*        error = NULL;
 
 	dsn_name = value_get_as_string (args[0]);
 	user_name = value_get_as_string (args[1]);
@@ -176,7 +184,7 @@ gnumeric_execSQL (FunctionEvalInfo *ei, GnmValue **args)
 
 	/* execute command */
 	cmd = gda_command_new (sql, GDA_COMMAND_TYPE_SQL, 0);
-	recset_list = gda_connection_execute_command (cnc, cmd, NULL);
+	recset_list = gda_connection_execute_command (cnc, cmd, NULL, &error);
 	gda_command_free (cmd);
 	if (recset_list) {
 		recset = (GdaDataModel *) recset_list->data;
@@ -187,8 +195,13 @@ gnumeric_execSQL (FunctionEvalInfo *ei, GnmValue **args)
 
 		g_list_foreach (recset_list, (GFunc) g_object_unref, NULL);
 		g_list_free (recset_list);
-	} else
-		ret = value_new_empty ();
+	} else {
+		if (error) {
+			ret = value_new_error (ei->pos, error->message);
+			g_error_free (error);
+		} else
+			ret = value_new_empty ();
+	}
 
 	return ret;
 }
@@ -196,12 +209,13 @@ gnumeric_execSQL (FunctionEvalInfo *ei, GnmValue **args)
 /*
  * readDBTable function
  */
-static char const *help_readDBTable = {
-	N_("@FUNCTION=READDBTABLE\n"
+static GnmFuncHelp const help_readDBTable[] = {
+    { GNM_FUNC_HELP_OLD,
+	F_("@FUNCTION=READDBTABLE\n"
 	   "@SYNTAX=READDBTABLE(dsn,username,password,table)\n"
 	   "@DESCRIPTION="
 	   "The READDBTABLE function lets you get the contents of"
-	   " a table, as stored in a database."
+	   " a table, as stored in a database. "
 	   "For using it, you need first to set up a libgda data source."
 	   "\n"
 	   "Note that this function returns all the rows in the given"
@@ -214,6 +228,8 @@ static char const *help_readDBTable = {
 	   " in the \"mydatasource\" GDA data source, you would use:\n"
 	   "READDBTABLE(\"mydatasource\",\"username\",\"password\",\"customers\")\n"
 	   "@SEEALSO=EXECSQL")
+    },
+    { GNM_FUNC_HELP_END }
 };
 
 static GnmValue *
@@ -228,6 +244,7 @@ gnumeric_readDBTable (FunctionEvalInfo *ei, GnmValue **args)
 	GdaDataModel*  recset;
 	GList*         recset_list;
 	GdaCommand*    cmd;
+	GError*        error = NULL;
 
 	dsn_name = value_get_as_string (args[0]);
 	user_name = value_get_as_string (args[1]);
@@ -243,7 +260,7 @@ gnumeric_readDBTable (FunctionEvalInfo *ei, GnmValue **args)
 
 	/* execute command */
 	cmd = gda_command_new (table, GDA_COMMAND_TYPE_TABLE, 0);
-	recset_list = gda_connection_execute_command (cnc, cmd, NULL);
+	recset_list = gda_connection_execute_command (cnc, cmd, NULL, &error);
 	gda_command_free (cmd);
 	if (recset_list) {
 		recset = (GdaDataModel *) recset_list->data;
@@ -254,14 +271,19 @@ gnumeric_readDBTable (FunctionEvalInfo *ei, GnmValue **args)
 
 		g_list_foreach (recset_list, (GFunc) g_object_unref, NULL);
 		g_list_free (recset_list);
-	} else
-		ret = value_new_empty ();
+	} else {
+		if (error) {
+			ret = value_new_error (ei->pos, error->message);
+			g_error_free (error);
+		} else
+			ret = value_new_empty ();
+	}
 
 	return ret;
 }
 
-void
-plugin_cleanup (void)
+G_MODULE_EXPORT void
+go_plugin_shutdown (GOPlugin *plugin, GOCmdContext *cc)
 {
 	/* close the connection pool */
 	if (GDA_IS_CLIENT (connection_pool)) {
@@ -271,7 +293,7 @@ plugin_cleanup (void)
 }
 
 GnmFuncDescriptor gdaif_functions[] = {
-	{"execSQL", "ssss", "dsn,username,password,sql", &help_execSQL, &gnumeric_execSQL, NULL, NULL, NULL },
-	{"readDBTable", "ssss", "dsn,username,password,table", &help_readDBTable, &gnumeric_readDBTable, NULL, NULL, NULL },
+	{"execSQL", "ssss", "dsn,username,password,sql", help_execSQL, &gnumeric_execSQL, NULL, NULL, NULL },
+	{"readDBTable", "ssss", "dsn,username,password,table", help_readDBTable, &gnumeric_readDBTable, NULL, NULL, NULL },
 	{NULL}
 };
