@@ -9,7 +9,7 @@
  * partially based on actual Oleo code.
  */
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include <gnumeric.h>
 #include "oleo.h"
 
@@ -19,7 +19,6 @@
 #include <value.h>
 #include <parse-util.h>
 #include <expr.h>
-#include <plugin-util.h>
 #include <sheet-style.h>
 #include <mstyle.h>
 #include <ranges.h>
@@ -29,6 +28,7 @@
 #include <gsf/gsf-input-textline.h>
 
 #include <string.h>
+#include <stdlib.h>
 
 #define OLEO_DEBUG 0
 
@@ -69,7 +69,7 @@ oleo_set_style (Sheet *sheet, int col, int row, GnmStyle *mstyle)
 		range.start.row = range.end.row = OLEO_TO_GNUMERIC (row);
 
 	/* sheet_style_set_range absorbs our reference */
-	mstyle_ref (mstyle);
+	gnm_style_ref (mstyle);
 	sheet_style_set_range (sheet, &range, mstyle);
 }
 
@@ -295,7 +295,7 @@ oleo_deal_with_format (OleoParseState *state, guint8 *str, int *ccol, int *crow,
 		       GnmStyle **style)
 {
 	char *ptr = str + 1;
-	GnmStyle *mstyle = mstyle_new_default ();
+	GnmStyle *mstyle = gnm_style_new_default ();
 	GString *fmt_string = g_string_new (NULL);
 
 	while (*ptr) {
@@ -322,18 +322,18 @@ oleo_deal_with_format (OleoParseState *state, guint8 *str, int *ccol, int *crow,
 			}
 			break;
 		case 'L':
-			mstyle_set_align_h (mstyle, HALIGN_LEFT);
+			gnm_style_set_align_h (mstyle, HALIGN_LEFT);
 			break;
 		case 'R':
-			mstyle_set_align_h (mstyle, HALIGN_RIGHT);
+			gnm_style_set_align_h (mstyle, HALIGN_RIGHT);
 	}
 	}
 	if (fmt_string->len)
-		mstyle_set_format_text (mstyle, fmt_string->str);
+		gnm_style_set_format_text (mstyle, fmt_string->str);
 	g_string_free (fmt_string, TRUE);
 
 	if (*style)
-		mstyle_unref (*style);
+		gnm_style_unref (*style);
 	*style = mstyle;
 }
 
@@ -343,7 +343,7 @@ oleo_new_sheet (Workbook *wb, int idx)
 	char  *sheet_name = g_strdup_printf (_("Sheet%d"), idx);
 	Sheet *sheet = sheet_new (wb, sheet_name);
 	g_free (sheet_name);
-	workbook_sheet_attach (wb, sheet, NULL);
+	workbook_sheet_attach (wb, sheet);
 
 	/* Ensure that things get rendered and spanned */
 	sheet_flag_recompute_spans (sheet);
@@ -375,7 +375,7 @@ oleo_read (IOContext *io_context, Workbook *wb, GsfInput *input)
 	guint8 *line;
 	OleoParseState state;
 
-	state.textline = gsf_input_textline_new (input);
+	state.textline = (GsfInputTextline *) gsf_input_textline_new (input);
 	/* This should probably come from import dialog.  */
 	state.converter = g_iconv_open ("UTF-8", "ISO-8859-1");
 	state.sheet = oleo_new_sheet (wb, ++sheetidx);
