@@ -113,7 +113,7 @@ static struct {
 		N_("Special functions") },
 	{ N_("Jukka-Pekka Iivonen"),	GNM_ANALYTICS|GNM_GUI|GNM_FEATURE_HACKER,
 		N_("Solver, lots of worksheet functions, and general trailblazer") },
-	{ N_("Jakub Jelinek"),		GNM_CORE,
+	{ N_("Jakub Jel\xc3\xadnek"),		GNM_CORE,
 		N_("One of the original core contributors") },
 	{ N_("Jakub Steiner"),		GNM_ART,
 		N_("Icons and Images") },
@@ -169,8 +169,6 @@ cb_plot_resize (FooCanvas *canvas, GtkAllocation *alloc, FooCanvasItem *ctrl)
 	foo_canvas_item_set (ctrl,
 		"w", (double)alloc->width,
 		"h", (double)alloc->height,
-		"logical_width_pts",  ((double)alloc->width)  * 72. / 96.,
-		"logical_height_pts", ((double)alloc->height) * 72. / 96.,
 		NULL);
 }
 static void
@@ -275,6 +273,7 @@ dialog_about (WorkbookControlGUI *wbcg)
 		"state", state, (GDestroyNotify)gnm_about_state_free);
 
 	state->graph = g_object_new (GOG_GRAPH_TYPE, NULL);
+	gog_graph_set_size (GOG_GRAPH (state->graph), 4 * 72.0, 4 * 72.0);
 	GOG_STYLED_OBJECT (state->graph)->style->fill.type = GOG_FILL_STYLE_GRADIENT;
 	GOG_STYLED_OBJECT (state->graph)->style->fill.pattern.back = 0xFFFF99FF;
 	GOG_STYLED_OBJECT (state->graph)->style->fill.gradient.dir = GO_GRADIENT_W_TO_E_MIRRORED;
@@ -318,12 +317,6 @@ dialog_about (WorkbookControlGUI *wbcg)
 	gog_style_set_fill_brightness (
 		GOG_STYLED_OBJECT (series)->style, 70.);
 
-	/* remove the default grid, its ugly here */
-	tmp = gog_object_get_child_by_role (chart,
-		gog_object_find_role_by_name (chart, "Grid"));
-	gog_object_clear_parent (tmp);
-	g_object_unref (tmp);
-
 	/* hide the X-axis */
 	tmp = gog_object_get_child_by_role (chart,
 		gog_object_find_role_by_name (chart, "X-Axis"));
@@ -339,7 +332,8 @@ dialog_about (WorkbookControlGUI *wbcg)
 		pango_font_description_from_string ("Sans 10"));
 
 	tmp = gog_object_add_by_name (chart, "Title", NULL);
-	gog_object_set_pos (tmp, GOG_POSITION_N | GOG_POSITION_ALIGN_START);
+	gog_object_set_position_flags (tmp, GOG_POSITION_N | GOG_POSITION_ALIGN_START,
+				       GOG_POSITION_COMPASS | GOG_POSITION_ALIGNMENT);
 	state->contributor_name = go_data_scalar_str_new ("", FALSE);
 	gog_dataset_set_dim (GOG_DATASET (tmp), 0, state->contributor_name, NULL);
 	state->contributor_style = GOG_STYLED_OBJECT (tmp)->style;
@@ -372,7 +366,8 @@ dialog_about (WorkbookControlGUI *wbcg)
 		GOG_STYLED_OBJECT (series)->style, 70.);
 
 	tmp = gog_object_add_by_name (state->graph, "Title", NULL);
-	gog_object_set_pos (tmp, GOG_POSITION_S | GOG_POSITION_ALIGN_END);
+	gog_object_set_position_flags (tmp, GOG_POSITION_S | GOG_POSITION_ALIGN_END,
+			    GOG_POSITION_COMPASS | GOG_POSITION_ALIGNMENT);
 	gog_dataset_set_dim (GOG_DATASET (tmp), 0,
 		go_data_scalar_str_new (
 			"Gnumeric " GNUMERIC_VERSION "\n"
@@ -383,7 +378,7 @@ dialog_about (WorkbookControlGUI *wbcg)
 		pango_font_description_from_string ("Sans Bold 12"));
 
 	state->canvas = foo_canvas_new ();
-	gtk_widget_set_size_request (state->canvas, 450, 400);
+	gtk_widget_set_size_request (state->canvas, 400, 350);
 	foo_canvas_scroll_to (FOO_CANVAS (state->canvas), 0, 0);
 
 	state->ctrl = foo_canvas_item_new (foo_canvas_root (FOO_CANVAS (state->canvas)),
@@ -401,7 +396,7 @@ dialog_about (WorkbookControlGUI *wbcg)
 	g_signal_connect (state->about, "response",
 		G_CALLBACK (gtk_widget_destroy), NULL);
 
-	state->timer = g_timeout_add_full (G_PRIORITY_LOW, 100,
+	state->timer = g_timeout_add_full (G_PRIORITY_LOW, 300,
 					   (GSourceFunc) cb_about_animate, state,
 					   NULL);
 }
