@@ -27,6 +27,7 @@ typedef struct _SheetObjectAnchor	SheetObjectAnchor;
 typedef struct _SheetObjectView		 SheetObjectView;
 typedef struct _SheetObjectViewContainer SheetObjectViewContainer;
 typedef struct _SheetObjectImageableIface SheetObjectImageableIface;
+typedef struct _SheetObjectExportableIface SheetObjectExportableIface;
 
 typedef struct _GnmDepContainer		GnmDepContainer;
 typedef struct _GnmDependent		GnmDependent;
@@ -91,13 +92,12 @@ typedef struct _ColRowIndexSet          ColRowIndexSet;
 typedef struct _GnmFont	        	GnmFont;
 typedef struct _GnmColor	        GnmColor;
 typedef struct _GnmBorder	        GnmBorder;
-typedef struct _GnmRow	        	GnmRow;
 typedef struct _GnmStyle		GnmStyle;
-
-typedef struct _SheetStyleData	        SheetStyleData;
-typedef struct _GnmStyleRegion	        GnmStyleRegion;
+typedef struct _GnmStyleRow        	GnmStyleRow;
 typedef GSList				GnmStyleList;
-
+typedef struct _GnmStyleRegion	        GnmStyleRegion;
+typedef struct _GnmStyleConditions	GnmStyleConditions;
+typedef struct _SheetStyleData	        SheetStyleData;
 typedef struct _FormatTemplate          FormatTemplate;	/* does not really belong here */
 
 typedef struct {
