@@ -3,6 +3,8 @@
 
 #include <goffice/utils/regutf8.h>
 
+extern const gchar *solver_max_time_err;
+
 void gutils_init (void);
 void gutils_shutdown (void);
 
@@ -21,6 +23,6 @@ char const *gnm_usr_dir	       (void);
 extern const char *gnumeric_lib_dir;
 extern const char *gnumeric_data_dir;
 
-int gnumeric_regcomp_XL (go_regex_t *preg, char const *pattern, int cflags);
+int gnm_regcomp_XL (GORegexp *preg, char const *pattern, int cflags);
 
 #endif /* GNUMERIC_UTILS_H */
