@@ -3,7 +3,7 @@
 /*
  * wbcg-actions.c: The callbacks and tables for all the menus and stock toolbars
  *
- * Copyright (C) 2003-2004 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2003-2005 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 #include <gnumeric-config.h>
@@ -166,13 +166,12 @@ static GNM_ACTION_DEF (cb_file_quit)
 	if (discard_all) {
 		workbook_set_dirty (wb_control_workbook (wbc), FALSE);
 		g_object_unref (wb_control_workbook (wbc));
-		for (ptr = clean_no_closed; ptr != NULL ; ptr = ptr->next)
+		for (ptr = clean_no_closed; ptr != NULL ; ptr = ptr->next) {
 			g_object_unref (ptr->data);
-	} else
-	/* only close pristine books if nothing was canceled. */
-	if (ok && wbcg_close_if_user_permits (wbcg,
-					      wb_control_view (wbc), TRUE, TRUE, ask_user)
-	    > 0)
+		}
+	} else if (ok && wbcg_close_if_user_permits (wbcg, wb_control_view (wbc),
+						     TRUE, TRUE, ask_user) > 0)
+		/* only close pristine books if nothing was canceled. */
 		for (ptr = clean_no_closed; ptr != NULL ; ptr = ptr->next)
 			g_object_unref (ptr->data);
 
@@ -204,7 +203,7 @@ static GNM_ACTION_DEF (cb_edit_delete_rows)
 	WorkbookControl *wbc   = WORKBOOK_CONTROL (wbcg);
 	SheetView       *sv    = wb_control_cur_sheet_view (wbc);
 	Sheet           *sheet = wb_control_cur_sheet (wbc);
-	GnmRange const *sel;
+	GnmRange const  *sel;
 	int rows;
 
 	if (!(sel = selection_first_range (sv, GO_CMD_CONTEXT (wbc), _("Delete"))))
@@ -430,9 +429,7 @@ static GNM_ACTION_DEF (cb_edit_fill_autofill)
 		gboolean do_loop;
 		GSList *merges, *ptr;
 
-		/* This could be more efficient, but it is not important */
-		if (range_trim (sheet, &src, TRUE) ||
-		    range_trim (sheet, &src, FALSE))
+		if (range_trim (sheet, &src, TRUE, TRUE))
 			return; /* Region totally empty */
 
 		/* trim is a bit overzealous, it forgets about merges */
@@ -1065,7 +1062,7 @@ static GNM_ACTION_DEF (cmd_create_ellipse)
 	{ create_object (wbcg, GNM_SO_FILLED_TYPE, "is-oval", TRUE, NULL); }
 
 void
-wbcg_set_selection_halign (WorkbookControlGUI *wbcg, StyleHAlignFlags halign)
+wbcg_set_selection_halign (WorkbookControlGUI *wbcg, GnmHAlign halign)
 {
 	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
 	WorkbookView	*wb_view;
@@ -1078,11 +1075,11 @@ wbcg_set_selection_halign (WorkbookControlGUI *wbcg, StyleHAlignFlags halign)
 	 * then revert to general */
 	wb_view = wb_control_view (wbc);
 	style = wb_view->current_format;
-	if (mstyle_get_align_h (style) == halign)
+	if (gnm_style_get_align_h (style) == halign)
 		halign = HALIGN_GENERAL;
 
-	style = mstyle_new ();
-	mstyle_set_align_h (style, halign);
+	style = gnm_style_new ();
+	gnm_style_set_align_h (style, halign);
 	cmd_selection_format (wbc, style, NULL, _("Set Horizontal Alignment"));
 }
 
@@ -1096,7 +1093,7 @@ static GNM_ACTION_DEF (cb_center_across_selection)
 	{ wbcg_set_selection_halign (wbcg, HALIGN_CENTER_ACROSS_SELECTION); }
 
 void
-wbcg_set_selection_valign (WorkbookControlGUI *wbcg, StyleVAlignFlags valign)
+wbcg_set_selection_valign (WorkbookControlGUI *wbcg, GnmVAlign valign)
 {
 	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
 	WorkbookView	*wb_view;
@@ -1109,14 +1106,14 @@ wbcg_set_selection_valign (WorkbookControlGUI *wbcg, StyleVAlignFlags valign)
 	 * then revert to general */
 	wb_view = wb_control_view (wbc);
 	style = wb_view->current_format;
-	if (mstyle_get_align_h (style) == valign) {
+	if (gnm_style_get_align_h (style) == valign) {
 		if (valign == VALIGN_BOTTOM)
 			return;
 		valign = VALIGN_BOTTOM;
 	}
 
-	style = mstyle_new ();
-	mstyle_set_align_v (style, valign);
+	style = gnm_style_new ();
+	gnm_style_set_align_v (style, valign);
 	cmd_selection_format (wbc, style, NULL, _("Set Vertical Alignment"));
 }
 
@@ -1161,7 +1158,7 @@ static GNM_ACTION_DEF (cb_unmerge_cells)
 
 static void
 toggle_font_attr (WorkbookControlGUI *wbcg, GtkToggleAction *act,
-		  MStyleElementType t, unsigned true_val, unsigned false_val)
+		  GnmStyleElement t, unsigned true_val, unsigned false_val)
 {
 	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
 	GnmStyle *new_style;
@@ -1197,13 +1194,13 @@ toggle_font_attr (WorkbookControlGUI *wbcg, GtkToggleAction *act,
 		return;
 	}
 
-	new_style = mstyle_new ();
+	new_style = gnm_style_new ();
 	switch (t) {
 	default :
-	case MSTYLE_FONT_BOLD:	 	mstyle_set_font_bold (new_style, val); break;
-	case MSTYLE_FONT_ITALIC:	mstyle_set_font_italic (new_style, val); break;
-	case MSTYLE_FONT_UNDERLINE:	mstyle_set_font_uline (new_style, val); break;
-	case MSTYLE_FONT_STRIKETHROUGH: mstyle_set_font_strike (new_style, val); break;
+	case MSTYLE_FONT_BOLD:	 	gnm_style_set_font_bold (new_style, val); break;
+	case MSTYLE_FONT_ITALIC:	gnm_style_set_font_italic (new_style, val); break;
+	case MSTYLE_FONT_UNDERLINE:	gnm_style_set_font_uline (new_style, val); break;
+	case MSTYLE_FONT_STRIKETHROUGH: gnm_style_set_font_strike (new_style, val); break;
 	};
 
 	cmd_selection_format (wbc, new_style, NULL, _("Set Font Style"));
@@ -1224,8 +1221,8 @@ static void
 apply_number_format (WorkbookControlGUI *wbcg,
 		     char const *translated_format, char const *descriptor)
 {
-	GnmStyle *mstyle = mstyle_new ();
-	mstyle_set_format_text (mstyle, translated_format);
+	GnmStyle *mstyle = gnm_style_new ();
+	gnm_style_set_format_text (mstyle, translated_format);
 	cmd_selection_format (WORKBOOK_CONTROL (wbcg), mstyle, NULL, descriptor);
 }
 
@@ -1306,10 +1303,10 @@ modify_format (WorkbookControlGUI *wbcg,
 	g_return_if_fail (wbv != NULL);
 	g_return_if_fail (wbv->current_format != NULL);
 
-	new_fmt = (*format_modify_fn) (mstyle_get_format (wbv->current_format));
+	new_fmt = (*format_modify_fn) (gnm_style_get_format (wbv->current_format));
 	if (new_fmt != NULL) {
-		GnmStyle *style = mstyle_new ();
-		mstyle_set_format (style, new_fmt);
+		GnmStyle *style = gnm_style_new ();
+		gnm_style_set_format (style, new_fmt);
 		cmd_selection_format (wbc, style, NULL, descriptor);
 		style_format_unref (new_fmt);
 	}
@@ -1332,13 +1329,13 @@ static GNM_ACTION_DEF (cb_format_inc_indent)
 	g_return_if_fail (wbv != NULL);
 	g_return_if_fail (wbv->current_format != NULL);
 
-	i = mstyle_get_indent (wbv->current_format);
+	i = gnm_style_get_indent (wbv->current_format);
 	if (i < 20) {
-		GnmStyle *style = mstyle_new ();
+		GnmStyle *style = gnm_style_new ();
 
-		if (HALIGN_LEFT != mstyle_get_align_h (wbv->current_format))
-			mstyle_set_align_h (style, HALIGN_LEFT);
-		mstyle_set_indent (style, i+1);
+		if (HALIGN_LEFT != gnm_style_get_align_h (wbv->current_format))
+			gnm_style_set_align_h (style, HALIGN_LEFT);
+		gnm_style_set_indent (style, i+1);
 		cmd_selection_format (wbc, style, NULL,
 			    _("Increase Indent"));
 	}
@@ -1354,11 +1351,11 @@ static GNM_ACTION_DEF (cb_format_dec_indent)
 	g_return_if_fail (wbv != NULL);
 	g_return_if_fail (wbv->current_format != NULL);
 
-	i = mstyle_get_indent (wbv->current_format);
+	i = gnm_style_get_indent (wbv->current_format);
 	if (i > 0) {
-		GnmStyle *style = mstyle_new ();
+		GnmStyle *style = gnm_style_new ();
 
-		mstyle_set_indent (style, i-1);
+		gnm_style_set_indent (style, i-1);
 		cmd_selection_format (wbc, style, NULL,
 			    _("Decrease Indent"));
 	}
@@ -1423,7 +1420,7 @@ static GNM_ACTION_DEF (cb_format_row_unhide)
 }
 
 /* Actions that are always sensitive */
-static const GtkActionEntry permanent_actions[] = {
+static GtkActionEntry const permanent_actions[] = {
 	{ "MenuFile",		NULL, N_("_File") },
 	{ "MenuEdit",		NULL, N_("_Edit") },
 		{ "MenuEditClear",	GTK_STOCK_CLEAR, N_("C_lear") },
@@ -1453,6 +1450,13 @@ static const GtkActionEntry permanent_actions[] = {
 		{ "MenuExternalData",	NULL,	N_("Get _External Data") },
 	{ "MenuHelp",	NULL,	N_("_Help") },
 
+	{ "FileClose", GTK_STOCK_CLOSE, NULL,
+		NULL, N_("Close the current file"),
+		G_CALLBACK (cb_file_close) },
+	{ "FileQuit", GTK_STOCK_QUIT, NULL,
+		NULL, N_("Quit the application"),
+		G_CALLBACK (cb_file_quit) },
+
 	{ "EditCut", GTK_STOCK_CUT, NULL,
 		NULL, N_("Cut the selection"),
 		G_CALLBACK (cb_edit_cut) },
@@ -1486,7 +1490,7 @@ static const GtkActionEntry permanent_actions[] = {
 		G_CALLBACK (cb_repeat) }
 };
 
-static const GtkActionEntry actions[] = {
+static GtkActionEntry const actions[] = {
 /* File */
 	{ "FileNew", GTK_STOCK_NEW, NULL,
 		NULL, N_("Create a new workbook"),
@@ -1518,12 +1522,6 @@ static const GtkActionEntry actions[] = {
 	{ "FilePreferences", GTK_STOCK_PREFERENCES, N_("Pre_ferences..."),
 		NULL, N_("Change Gnumeric Preferences"),
 		G_CALLBACK (cb_file_preferences) },
-	{ "FileClose", GTK_STOCK_CLOSE, NULL,
-		NULL, N_("Close the current file"),
-		G_CALLBACK (cb_file_close) },
-	{ "FileQuit", GTK_STOCK_QUIT, NULL,
-		NULL, N_("Quit the application"),
-		G_CALLBACK (cb_file_quit) },
 
 #warning new hook put here to avoid patch conflict
 	{ "FileSummary_new", GTK_STOCK_PROPERTIES, N_("NEW Proper_ties..."),
@@ -1575,6 +1573,9 @@ static const GtkActionEntry actions[] = {
 	{ "EditSelectInputs", NULL, N_("Select _Inputs"),
 		"<control>bracketleft", N_("Select all the cells are used by the current edit cell"),
 		G_CALLBACK (cb_edit_select_inputs) },
+	{ "EditMetadata", NULL, N_("Edit Metadata"),
+		"<control>bracketleft", N_("Edit the document's extra information (metadata)"),
+		G_CALLBACK (cb_new_doc_metadata) },
 
 /* Edit -> Fill */
 	{ "EditFillAutofill", NULL, N_("Auto_fill"),
@@ -2022,6 +2023,7 @@ static GNM_ACTION_DEF (cb_sheet_pref_ ## flag )				\
 	if (!wbcg->updating_ui) {					\
 		Sheet *sheet = wbcg_cur_sheet (wbcg);			\
 		go_object_toggle (sheet, property);			\
+		sheet_update (sheet);					\
 	}								\
 }
 
@@ -2033,8 +2035,9 @@ TOGGLE_HANDLER (hide_row_header, "display-row-header")
 TOGGLE_HANDLER (display_outlines, "display-outlines")
 TOGGLE_HANDLER (outline_symbols_below, "display-outlines-below")
 TOGGLE_HANDLER (outline_symbols_right, "display-outlines-right")
+TOGGLE_HANDLER (use_r1c1, "use-r1c1")
 
-static const GtkToggleActionEntry toggle_actions[] = {
+static GtkToggleActionEntry const toggle_actions[] = {
 	{ "SheetDisplayOutlines", NULL, N_("Display _Outlines"),
 		"<control>8", N_("Toggle whether or not to display outline groups"),
 		G_CALLBACK (cb_sheet_pref_display_outlines) },
@@ -2059,6 +2062,9 @@ static const GtkToggleActionEntry toggle_actions[] = {
 	{ "SheetHideRowHeader", NULL, N_("Hide _Row Headers"),
 		NULL, N_("Toggle whether or not to display row headers"),
 		G_CALLBACK (cb_sheet_pref_hide_row_header) },
+	{ "SheetUseR1C1", NULL, N_("Use R1C1 N_otation "),
+		NULL, N_("Display addresses as R1C1 or A1"),
+		G_CALLBACK (cb_sheet_pref_use_r1c1) },
 
 	{ "AlignLeft", GTK_STOCK_JUSTIFY_LEFT,
 		N_("_Left Align"), NULL,
@@ -2097,11 +2103,11 @@ static const GtkToggleActionEntry toggle_actions[] = {
 	        G_CALLBACK (cb_view_statusbar), TRUE },
 
 	{ "ViewFullScreen", GTK_STOCK_ZOOM_FIT,
-		N_("F_ull Screen..."), "F11",
+		N_("F_ull Screen"), "F11",
 		N_("in or out"), G_CALLBACK (cb_view_fullscreen), FALSE }
 };
 
-static const GtkToggleActionEntry font_toggle_actions[] = {
+static GtkToggleActionEntry const font_toggle_actions[] = {
 	{ "FontBold", GTK_STOCK_BOLD,
 		N_("_Bold"), "<control>B",	/* ALSO "<control>2" */
 		N_("Bold"), G_CALLBACK (cb_font_bold), FALSE },
