@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -1037,41 +1037,18 @@ wbcg_sheet_focus (WorkbookControl *wbc, Sheet *sheet)
 	}
 }
 
-/*
- * Move a sheet's tab into position.  Note, that old_pos is an index_in_wb
- * and that the workbook's sheet array has already been changed.
- */
 static void
-wbcg_sheet_move (WorkbookControl *wbc, Sheet *sheet, int old_pos)
+wbcg_sheet_order_changed (WorkbookControlGUI *wbcg, Workbook const *wb)
 {
-	WorkbookControlGUI *wbcg = (WorkbookControlGUI *)wbc;
-	int p_src, p_dst;
-	int i, di, count, new_pos;
+	int i;
+	Sheet const *sheet;
 	SheetControlGUI *scg;
 
-	g_return_if_fail (IS_SHEET (sheet));
-
-	new_pos = sheet->index_in_wb;
-	count = workbook_sheet_count (sheet->workbook);
-
-	p_src = wbcg_sheet_to_page_index (wbcg, sheet, &scg);
-        if (p_src < 0)
-		return;
-
-	di = (new_pos > old_pos) ? +1 : -1;
-	p_dst = (new_pos > old_pos) ? count - 1 : 0;
-	for (i = new_pos + di; i >= 0 && i < count; i += di) {
-		Sheet *sheet_i = workbook_sheet_by_index (sheet->workbook, i);
-		int p = wbcg_sheet_to_page_index (wbcg, sheet_i, NULL);
-		if (p >= 0) {
-			p_dst = p - di;
-			break;
-		}
-	}
-
+	for (i = 0 ; i < workbook_sheet_count (wb); i++)
+		if (NULL != (sheet = wbcg_page_index_to_sheet (wbcg, i, &scg)) &&
+		    sheet->index_in_wb != i)
 	gtk_notebook_reorder_child (wbcg->notebook,
-				    GTK_WIDGET (scg->table),
-				    p_dst);
+				GTK_WIDGET (scg->table), sheet->index_in_wb);
 }
 
 static void
@@ -1245,8 +1222,8 @@ wbcg_error_error_info (GOCmdContext *cc, ErrorInfo *error)
  */
 int
 wbcg_close_if_user_permits (WorkbookControlGUI *wbcg,
-				WorkbookView *wb_view, gboolean close_clean,
-				gboolean exiting, gboolean ask_user)
+			    WorkbookView *wb_view, gboolean close_clean,
+			    gboolean exiting, gboolean ask_user)
 {
 	gboolean   can_close = TRUE;
 	gboolean   done      = FALSE;
@@ -1274,7 +1251,7 @@ wbcg_close_if_user_permits (WorkbookControlGUI *wbcg,
 	while (workbook_is_dirty (wb) && !done) {
 		GtkWidget *d;
 		char *msg;
-		const char *wb_uri = workbook_get_uri (wb);
+		char const *wb_uri = workbook_get_uri (wb);
 
 		iteration++;
 
@@ -1296,30 +1273,25 @@ wbcg_close_if_user_permits (WorkbookControlGUI *wbcg,
 
 		if (exiting) {
 			int n_of_wb = g_list_length (gnm_app_workbook_list ());
-			if (n_of_wb > 1)
-			{
-			  	gnumeric_dialog_add_button (GTK_DIALOG(d), _("Discard all"), 
-							    GTK_STOCK_DELETE, GNM_RESPONSE_DISCARD_ALL);
-				gnumeric_dialog_add_button (GTK_DIALOG(d), _("Discard"), 
-							    GTK_STOCK_DELETE, GTK_RESPONSE_NO);
-				gnumeric_dialog_add_button (GTK_DIALOG(d), _("Save all"), 
-							    GTK_STOCK_SAVE, GNM_RESPONSE_SAVE_ALL);
-				gnumeric_dialog_add_button (GTK_DIALOG(d), _("Don't quit"), 
-							    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
+			if (n_of_wb > 1) {
+				go_gtk_dialog_add_button (GTK_DIALOG(d), _("Discard all"), 
+					GTK_STOCK_DELETE, GNM_RESPONSE_DISCARD_ALL);
+				go_gtk_dialog_add_button (GTK_DIALOG(d), _("Discard"), 
+					GTK_STOCK_DELETE, GTK_RESPONSE_NO);
+				go_gtk_dialog_add_button (GTK_DIALOG(d), _("Save all"), 
+					GTK_STOCK_SAVE, GNM_RESPONSE_SAVE_ALL);
+				go_gtk_dialog_add_button (GTK_DIALOG(d), _("Don't quit"), 
+					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
+			} else {
+				go_gtk_dialog_add_button (GTK_DIALOG(d), _("Discard"),
+					GTK_STOCK_DELETE, GTK_RESPONSE_NO);
+				go_gtk_dialog_add_button (GTK_DIALOG(d), _("Don't quit"), 
+					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
 			}
-			else
-			{
-				gnumeric_dialog_add_button (GTK_DIALOG(d), _("Discard"),
-							    GTK_STOCK_DELETE, GTK_RESPONSE_NO);
-				gnumeric_dialog_add_button (GTK_DIALOG(d), _("Don't quit"), 
-							    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
-			}
-		} 
-		else
-		{
-			gnumeric_dialog_add_button (GTK_DIALOG(d), _("Discard"), 
+		} else {
+			go_gtk_dialog_add_button (GTK_DIALOG(d), _("Discard"), 
 						    GTK_STOCK_DELETE, GTK_RESPONSE_NO);
-			gnumeric_dialog_add_button (GTK_DIALOG(d), _("Don't close"), 
+			go_gtk_dialog_add_button (GTK_DIALOG(d), _("Don't close"), 
 						    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
 		}
 
@@ -1477,7 +1449,7 @@ cb_workbook_debug_info (WorkbookControlGUI *wbcg)
 
 	if (dependency_debugging > 0) {
 		WORKBOOK_FOREACH_SHEET (wb, sheet,
-			g_print ("Dependencies for %s:\n", sheet->name_unquoted);
+			g_printerr ("Dependencies for %s:\n", sheet->name_unquoted);
 			gnm_dep_container_dump (sheet->deps););
 	}
 
@@ -2137,9 +2109,9 @@ static gboolean
 cb_wbcg_drag_motion (GtkWidget *widget, GdkDragContext *context,
 		     gint x, gint y, guint time, WorkbookControlGUI *wbcg)
 {
-	GtkWidget *source_widget;
+	GtkWidget *source_widget = gtk_drag_get_source_widget (context);
 
-	source_widget = gtk_drag_get_source_widget (context);
+	g_warning ("wbcg motion");
 	if (IS_EDITABLE_LABEL (source_widget)) {
 		GtkWidget *label;
 
@@ -2147,24 +2119,23 @@ cb_wbcg_drag_motion (GtkWidget *widget, GdkDragContext *context,
 		 * drag motion over a label.
 		 */
 		label = wbcg_get_label_for_position (wbcg, source_widget, x);
-		return (cb_sheet_label_drag_motion (label, context, x, y,
-						    time, wbcg));
+		return cb_sheet_label_drag_motion (label, context, x, y,
+						    time, wbcg);
 	}
 
-	return (TRUE);
+	return TRUE;
 }
 
 static void
 cb_wbcg_drag_leave (GtkWidget *widget, GdkDragContext *context,
 		    gint x, gint y, guint time, WorkbookControlGUI *wbcg)
 {
-	GtkWidget *source_widget, *arrow;
+	GtkWidget *source_widget = gtk_drag_get_source_widget (context);
 
-	source_widget = gtk_drag_get_source_widget (context);
-	if (IS_EDITABLE_LABEL (source_widget)) {
-		arrow = g_object_get_data (G_OBJECT (source_widget), "arrow");
-		gtk_widget_hide (arrow);
-	}
+	g_warning ("leave");
+	if (IS_EDITABLE_LABEL (source_widget))
+		gtk_widget_hide (
+			g_object_get_data (G_OBJECT (source_widget), "arrow"));
 }
 
 static void
@@ -2175,8 +2146,7 @@ cb_wbcg_drag_data_received (GtkWidget *widget, GdkDragContext *context,
 	gchar *target_type = gdk_atom_name (selection_data->target);
 
 	if (!strcmp (target_type, "text/uri-list")) { /* filenames from nautilus */
-		scg_drag_data_received 
-			(wbcg_cur_scg (wbcg), 
+		scg_drag_data_received (wbcg_cur_scg (wbcg), 
 			 gtk_drag_get_source_widget (context), 0, 0, 
 			 selection_data);
 	} else if (!strcmp (target_type, "GNUMERIC_SHEET")) {
@@ -2346,18 +2316,17 @@ wbcg_set_toplevel (WorkbookControlGUI *wbcg, GtkWidget *w)
 	gtk_drag_dest_set (GTK_WIDGET (w),
 		GTK_DEST_DEFAULT_ALL, drag_types, G_N_ELEMENTS (drag_types),
 		GDK_ACTION_COPY | GDK_ACTION_MOVE);
-	g_signal_connect (w, "drag_data_received",
+	g_signal_connect (w, "drag-data-received",
 		G_CALLBACK (cb_wbcg_drag_data_received), wbcg);
-	g_signal_connect (w, "drag_motion",
+	g_signal_connect (w, "drag-motion",
 		G_CALLBACK (cb_wbcg_drag_motion), wbcg);
-	g_signal_connect (w, "drag_leave",
+	g_signal_connect (w, "drag-leave",
 		G_CALLBACK (cb_wbcg_drag_leave), wbcg);
 #if 0
 	g_signal_connect (G_OBJECT (gcanvas),
-		"drag_data_get",
+		"drag-data-get",
 		G_CALLBACK (wbcg_drag_data_get), WORKBOOK_CONTROL (wbc));
 #endif
-
 }
 
 static int
@@ -2464,6 +2433,7 @@ cb_graph_dim_editor_update (GnmExprEntry *gee,
 
 	g_object_get (G_OBJECT (gee), "scg", &scg, NULL);
 	sheet = sc_sheet (SHEET_CONTROL (scg));
+	g_object_unref (G_OBJECT (scg));
 
 	/* If we are setting something */
 	if (!gnm_expr_entry_is_blank (editor->entry)) {
@@ -2622,7 +2592,6 @@ workbook_control_gui_class_init (GObjectClass *object_class)
 	wbc_class->sheet.add        = wbcg_sheet_add;
 	wbc_class->sheet.remove	    = wbcg_sheet_remove;
 	wbc_class->sheet.focus	    = wbcg_sheet_focus;
-	wbc_class->sheet.move	    = wbcg_sheet_move;
 	wbc_class->sheet.remove_all = wbcg_sheet_remove_all;
 
 	wbc_class->undo_redo.labels   = wbcg_undo_redo_labels;
@@ -2679,11 +2648,13 @@ workbook_control_gui_init (WorkbookControlGUI *wbcg)
 }
 
 GSF_CLASS_FULL (WorkbookControlGUI, workbook_control_gui,
-		workbook_control_gui_class_init, workbook_control_gui_init,
-		WORKBOOK_CONTROL_TYPE, G_TYPE_FLAG_ABSTRACT,
+		NULL, NULL, workbook_control_gui_class_init, NULL,
+		workbook_control_gui_init, WORKBOOK_CONTROL_TYPE, G_TYPE_FLAG_ABSTRACT,
 		GSF_INTERFACE (wbcg_go_plot_data_allocator_init, GOG_DATA_ALLOCATOR_TYPE);
 		GSF_INTERFACE (wbcg_gnm_cmd_context_init, GO_CMD_CONTEXT_TYPE))
 
+/* Move the rubber bands if we are the source */
+
 static void
 wbcg_create (WorkbookControlGUI *wbcg,
 	     WorkbookView *optional_view,
@@ -2711,6 +2682,9 @@ wbcg_create (WorkbookControlGUI *wbcg,
 		wb_control_style_feedback (wbc, NULL);
 		cb_zoom_change (sheet, NULL, wbcg);
 	}
+	g_signal_connect_object (G_OBJECT (wbv->wb),
+		"sheet-order-changed",
+		G_CALLBACK (wbcg_sheet_order_changed), wbcg, G_CONNECT_SWAPPED);
 
 	if (optional_screen)
 		gtk_window_set_screen (wbcg->toplevel, optional_screen);
