@@ -59,7 +59,6 @@ wbcg_auto_complete_destroy (WorkbookControlGUI *wbcg)
 	}
 
 	wbcg->auto_completing = FALSE;
-
 }
 
 /**
@@ -121,7 +120,7 @@ wbcg_edit_finish (WorkbookControlGUI *wbcg, WBCEditResult result,
 		char const *expr_txt = NULL;
 
 		/* BE CAREFUL the standard fmts must not NOT include '@' */
-		GnmValue *value = format_match (txt, mstyle_get_format (mstyle),
+		GnmValue *value = format_match (txt, gnm_style_get_format (mstyle),
 						workbook_date_conv (sheet->workbook));
 		if (value != NULL)
 			value_release (value);
@@ -307,9 +306,8 @@ workbook_edit_complete_notify (char const *text, void *closure)
 }
 
 static void
-entry_changed (GtkEntry *entry, void *data)
+cb_entry_changed (GtkEntry *entry, WorkbookControlGUI *wbcg)
 {
-	WorkbookControlGUI *wbcg = data;
 	char const *text;
 	int text_len;
 	WorkbookView *wbv = wb_control_view (WORKBOOK_CONTROL (wbcg));
@@ -480,15 +478,15 @@ cb_entry_cursor_pos (WorkbookControlGUI *wbcg)
 
 	/* Make bold/italic/etc buttons show the right thing.  */
 	{
-		GnmStyle *style = mstyle_new ();
+		GnmStyle *style = gnm_style_new ();
 		GSList *ptr, *attrs = attrs_at_byte (wbcg->edit_line.full_content, target_pos_in_bytes);
 		for (ptr = attrs; ptr != NULL ; ptr = ptr->next) {
 			PangoAttribute *attr = ptr->data;
-			mstyle_set_from_pango_attribute (style, attr);
+			gnm_style_set_from_pango_attribute (style, attr);
 			pango_attribute_destroy (attr);
 		}
 		wb_control_style_feedback (WORKBOOK_CONTROL (wbcg), style);
-		mstyle_unref (style);
+		gnm_style_unref (style);
 		g_slist_free (attrs);
 	}
 
@@ -557,7 +555,12 @@ cb_entry_delete_text (GtkEditable    *editable,
 		      gint            end_pos,
 		      WorkbookControlGUI *wbcg)
 {
-	wbcg->auto_completing = FALSE;
+	if (wbcg->auto_completing) {
+		wbcg_auto_complete_destroy (wbcg);
+		SCG_FOREACH_PANE (wbcg_cur_scg (wbcg), pane,
+			if (pane->editor != NULL)
+				foo_canvas_item_request_update (FOO_CANVAS_ITEM (pane->editor)););
+	}
 
 	if (wbcg->edit_line.full_content) {
 		char const *str = gtk_entry_get_text (GTK_ENTRY (editable));
@@ -587,7 +590,7 @@ wbcg_edit_init_markup (WorkbookControlGUI *wbcg, PangoAttrList *markup)
 	g_return_if_fail (wbcg->edit_line.full_content == NULL);
 
 	wbcg->edit_line.markup = markup;
-	wbcg->edit_line.full_content = mstyle_generate_attrs_full (
+	wbcg->edit_line.full_content = gnm_style_generate_attrs_full (
 		sheet_style_get (sv->sheet, sv->edit_pos.col, sv->edit_pos.row));
 	pango_attr_list_splice (wbcg->edit_line.full_content, markup, 0, 0);
 	wbcg->edit_line.cur_fmt = pango_attr_list_copy (markup);
@@ -692,7 +695,7 @@ wbcg_edit_start (WorkbookControlGUI *wbcg,
 	 * information if we look at the selection.
 	 */
 	if (wb_view_is_protected (wbv, TRUE) &&
-	    mstyle_get_content_locked (sheet_style_get (sv->sheet, col, row))) {
+	    gnm_style_get_content_locked (sheet_style_get (sv->sheet, col, row))) {
 		char *pos =  g_strdup_printf ( _("%s!%s is locked"),
 			sv->sheet->name_quoted, cell_coord_name (col, row));
 		go_cmd_context_error_invalid (GO_CMD_CONTEXT (wbcg), pos,
@@ -736,8 +739,8 @@ wbcg_edit_start (WorkbookControlGUI *wbcg,
 	/* Redraw the cell contents in case there was a span */
 	sheet_redraw_region (sv->sheet, col, row, col, row);
 
-	/* Activate auto-completion if this is not an expression */
-	if (wbv->do_auto_completion &&
+	if (cursorp && /* autocompletion code will not work in the edit line */
+	    wbv->do_auto_completion &&
 	    (text == NULL || g_unichar_isalpha (g_utf8_get_char (text)))) {
 		wbcg->auto_complete = complete_sheet_new (
 			sv->sheet, col, row,
@@ -768,7 +771,7 @@ wbcg_edit_start (WorkbookControlGUI *wbcg,
 	wbcg->edit_line.signal_changed = g_signal_connect (
 		G_OBJECT (wbcg_get_entry (wbcg)),
 		"changed",
-		G_CALLBACK (entry_changed), wbcg);
+		G_CALLBACK (cb_entry_changed), wbcg);
 	wbcg->edit_line.signal_insert = g_signal_connect (
 		G_OBJECT (wbcg_get_entry (wbcg)),
 		"insert-text",
