@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 #include <gnumeric-config.h>
@@ -207,7 +207,7 @@ wb_view_format_feedback (WorkbookView *wbv, gboolean display)
 		return;
 
 	style = sheet_style_get (sv->sheet, sv->edit_pos.col, sv->edit_pos.row);
-	sf_style = mstyle_get_format (style);
+	sf_style = gnm_style_get_format (style);
 	if (style_format_is_general (sf_style) &&
 	    (cell = sheet_cell_get (sv->sheet, sv->edit_pos.col, sv->edit_pos.row)) &&
 	    cell->value && VALUE_FMT (cell->value))
@@ -218,14 +218,14 @@ wb_view_format_feedback (WorkbookView *wbv, gboolean display)
 	if (style_format_equal (sf_cell, sf_style)) {
 		if (style == wbv->current_format)
 			return;
-		mstyle_ref (style);
+		gnm_style_ref (style);
 	} else {
-		style = mstyle_copy (style);
-		mstyle_set_format (style, sf_cell);
+		style = gnm_style_dup (style);
+		gnm_style_set_format (style, sf_cell);
 	}
 
 	if (wbv->current_format != NULL)
-		mstyle_unref (wbv->current_format);
+		gnm_style_unref (wbv->current_format);
 	wbv->current_format = style;
 
 	if (display) {
@@ -539,7 +539,7 @@ wb_view_finalize (GObject *object)
 		wbv->auto_expr_value_as_string = NULL;
 	}
 	if (wbv->current_format != NULL) {
-		mstyle_unref (wbv->current_format);
+		gnm_style_unref (wbv->current_format);
 		wbv->current_format = NULL;
 	}
 
@@ -622,14 +622,16 @@ wbv_save_to_uri (WorkbookView *wbv, GOFileSaver const *fs,
 	if (output != NULL) {
 		GError const *save_err;
 
-		g_print ("Writing %s\n", uri);
-		go_file_saver_save (fs, io_context, wbv, GSF_OUTPUT (output));
-		save_err = gsf_output_error (GSF_OUTPUT (output));
+		g_printerr ("Writing %s\n", uri);
+		go_file_saver_save (fs, io_context, wbv, output);
+		gsf_output_close (output);
+		save_err = gsf_output_error (output);
 		if (save_err) {
 			msg = g_strdup (save_err->message);
-			g_object_unref (G_OBJECT (output));
+			g_printerr ("  ==> %s\n", msg);
+			g_object_unref (output);
 		} else {
-			g_object_unref (G_OBJECT (output));
+			g_object_unref (output);
 			return;
 		}
 	}
@@ -1019,7 +1021,7 @@ wb_view_new_from_uri (char const *uri,
 	if (input != NULL) {
 		WorkbookView *res;
 
-		g_print ("Reading %s\n", uri);
+		g_printerr ("Reading %s\n", uri);
 		res = wb_view_new_from_input (input,
 					      optional_fmt, io_context,
 					      optional_enc);
