@@ -9,7 +9,7 @@
  *
  * (C) 1998, 1999, 2000 Miguel de Icaza
  * (C) 2000-2001 Ximian, Inc.
- * (C) 2002 Jody Goldberg
+ * (C) 2002-2005 Jody Goldberg
  */
 #include <gnumeric-config.h>
 #include <glib/gi18n.h>
@@ -82,13 +82,6 @@ workbook_dispose (GObject *wb_object)
 
 	wb->during_destruction = TRUE;
 
-	if (wb->uri) {
-		if (wb->file_format_level >= FILE_FL_MANUAL_REMEMBER)
-			gnm_app_history_add (wb->uri);
-	       g_free (wb->uri);
-	       wb->uri = NULL;
-	}
-
 	if (wb->file_saver)
 		workbook_set_saveinfo (wb, wb->file_format_level, NULL);
 
@@ -117,16 +110,14 @@ workbook_dispose (GObject *wb_object)
 		 * be ok for debug code.
 		 */
 		if (gnumeric_debugging > 0) {
-			g_print ("Dependencies for %s:\n", sheet->name_unquoted);
+			g_printerr ("Dependencies for %s:\n", sheet->name_unquoted);
 			gnm_dep_container_dump (sheet->deps);
 		}
 	}
 
 	/* Now remove the sheets themselves */
-	for (ptr = sheets; ptr != NULL ; ptr = ptr->next) {
-		Sheet *sheet = ptr->data;
-		workbook_sheet_delete (sheet);
-	}
+	for (ptr = sheets; ptr != NULL ; ptr = ptr->next)
+		workbook_sheet_delete (ptr->data);
 	g_list_free (sheets);
 
 	/* TODO : This should be earlier when we figure out how to deal with
@@ -147,6 +138,14 @@ workbook_dispose (GObject *wb_object)
 		wb->sheet_local_functions = NULL;
 	}
 
+	/* do this last so that we can identify it after a crash */
+	if (wb->uri) {
+		if (wb->file_format_level >= FILE_FL_MANUAL_REMEMBER)
+			gnm_app_history_add (wb->uri);
+		g_free (wb->uri);
+		wb->uri = NULL;
+	}
+
 	workbook_parent_class->dispose (wb_object);
 }
 
@@ -930,32 +929,26 @@ workbook_sheet_hide_controls (Workbook *wb, Sheet *sheet)
 	if (!wb->during_destruction)
 		focus = workbook_focus_other_sheet (wb, sheet);
 
-	/* Remove all controls and views.  */
-	WORKBOOK_FOREACH_VIEW (wb, wbv,
-		wb_view_sheet_remove (wbv, sheet););
+	WORKBOOK_FOREACH_CONTROL (wb, wbv, wbc,
+		wb_control_sheet_remove (wbc, sheet););
 
 	return focus != NULL;
 }
 
-static void
-workbook_sheet_unhide_controls (Workbook *wb, Sheet *sheet)
-{
-	g_return_if_fail (IS_WORKBOOK (wb));
-	g_return_if_fail (IS_SHEET (sheet));
-
-	WORKBOOK_FOREACH_VIEW (wb, wbv,
-		if (sheet_get_view (sheet, wbv) == NULL)
-			wb_view_sheet_add (wbv, sheet););
-}
-
 static void
 cb_sheet_visibility_change (Sheet *sheet,
 			    G_GNUC_UNUSED GParamSpec *pspec,
 			    G_GNUC_UNUSED gpointer data)
 {
-	if (sheet->visibility == GNM_SHEET_VISIBILITY_VISIBLE)
-		workbook_sheet_unhide_controls (sheet->workbook, sheet);
-	else
+	g_return_if_fail (IS_SHEET (sheet));
+
+	if (sheet->visibility == GNM_SHEET_VISIBILITY_VISIBLE) {
+		SheetView *sv;
+		WORKBOOK_FOREACH_CONTROL (sheet->workbook, wbv, wbc, {
+			sv = sheet_get_view (sheet, wbv);
+			if (NULL == sv_get_control (sv, wbc))
+				wb_control_sheet_add (wbc, sv);});
+	} else
 		workbook_sheet_hide_controls (sheet->workbook, sheet);
 }
 
@@ -1079,9 +1072,7 @@ workbook_sheet_delete (Sheet *sheet)
 	post_sheet_index_change (wb);
 
 	/* Clear the controls first, before we potentially update */
-	SHEET_FOREACH_VIEW (sheet, view, {
-		sv_dispose (view);
-	});
+	SHEET_FOREACH_VIEW (sheet, view, sv_dispose (view););
 
 	g_signal_emit_by_name (G_OBJECT (sheet), "detached_from_workbook", wb);
 	g_object_unref (sheet);
@@ -1122,8 +1113,6 @@ workbook_sheet_move (Sheet *sheet, int direction)
 			sheet->index_in_wb = max_pos;
 		}
 
-		WORKBOOK_FOREACH_CONTROL (wb, view, control,
-			wb_control_sheet_move (control, sheet, old_pos););
 		sheet_set_dirty (sheet, TRUE);
 	}
 
@@ -1185,113 +1174,6 @@ workbook_sheet_get_free_name (Workbook *wb,
 	return name;
 }
 
-/**
- * workbook_sheet_rename_check:
- * @wb:          workbook to look for
- * @sheet_indices:   list of sheet indices (ignore -1)
- * @new_names:   list of new names
- *
- * Check whether changing of the names of the sheets as indicated
- * would be possible.
- *
- * Returns TRUE when it is possible.
- **/
-gboolean
-workbook_sheet_rename_check (Workbook *wb,
-			     GSList *sheet_indices,
-			     GSList *new_names,
-			     GSList *sheet_indices_deleted,
-			     GOCmdContext *cc)
-{
-	GSList *sheet_index = sheet_indices;
-	GSList *new_name = new_names;
-	gint max_sheet = workbook_sheet_count (wb);
-
-	/* First we check whether the sheet_indices are valid */
-	while (sheet_index) {
-		gint n = GPOINTER_TO_INT (sheet_index->data);
-		if (n < -1 || n >= max_sheet) {
-			g_warning ("Invalid sheet index %i", n);
-			return FALSE;
-		}
-		sheet_index = sheet_index->next;
-	}
-
-
-	/* Then we just check whether the names are valid.*/
-	sheet_index = sheet_indices;
-	while (new_name && sheet_index) {
-		if (new_name != NULL) {
-			char *the_new_name = new_name->data;
-			Sheet *tmp;
-
-			if (the_new_name == NULL && 
-			    GPOINTER_TO_INT (sheet_index->data) != -1) {
-				go_cmd_context_error_invalid (cc, 
-					_("Sheet name is NULL"), the_new_name);
-				return FALSE;
-			}
-
-			if (the_new_name != NULL) {
-				
-				/* Is the sheet name valid utf-8 ?*/
-				if (!g_utf8_validate (the_new_name, -1, NULL)) {
-					go_cmd_context_error_invalid (cc, 
-						_("Sheet name is not valid utf-8"),
-						the_new_name);
-					return FALSE;
-				}
-				
-				/* Is the sheet name to short ?*/
-				if (1 > g_utf8_strlen (the_new_name, -1)) {
-					go_cmd_context_error_invalid (cc,
-						_("Sheet name must have at least 1 letter"),
-						the_new_name);
-					return FALSE;
-				}
-				
-				/* Is the sheet name already in use ?*/
-				tmp = workbook_sheet_by_name (wb, the_new_name);
-				
-				if (tmp != NULL) {
-					/* Perhaps it is a sheet also to be renamed */
-					GSList *tmp_sheets = g_slist_find 
-						(sheet_indices, 
-						 GINT_TO_POINTER(tmp->index_in_wb));
-					if (NULL == tmp_sheets) {
-					/* Perhaps it is a sheet to be deleted */					
-						tmp_sheets = g_slist_find 
-						    (sheet_indices_deleted, 
-						     GINT_TO_POINTER(tmp->index_in_wb));
-					}
-
-					if (NULL == tmp_sheets) {
-						go_cmd_context_error_invalid (cc,
-							_("There is already a sheet named"),
-							the_new_name);
-						return FALSE;
-					}
-				}
-				
-				/* Will we try to use the same name a second time ?*/
-				if (new_name->next != NULL &&
-				    g_slist_find_custom (new_name->next, 
-							 the_new_name, 
-							 go_str_compare) != NULL) {
-					go_cmd_context_error_invalid (cc,
-						_("You may not use this name twice"),
-						the_new_name);
-					return FALSE;
-				}
-			}
-		}
-		new_name = new_name->next;
-		sheet_index = sheet_index->next;
-	}
-	
-	return TRUE;
-}
-
 /**
  * workbook_sheet_rename:
  * @wb:          workbook to look for
@@ -1336,75 +1218,6 @@ workbook_sheet_rename (Workbook *wb,
 	return FALSE;
 }
 
-/**
- * workbook_sheet_change_protection:
- * @wb:          workbook to look for
- * @sheets   :   list of sheet indices (ignore -1)
- * @locks    :   list of new locks
- *
- * Adjusts the locks
- *
- * Returns FALSE when it was successful
- **/
-gboolean    
-workbook_sheet_change_protection  (Workbook *wb,
-				   GSList *sheets,
-				   GSList *locks)
-{
-	g_return_val_if_fail (g_slist_length (sheets) 
-			      == g_slist_length (locks), 
-			      TRUE);
-
-	while (sheets) {
-		int sheetno = GPOINTER_TO_INT (sheets->data);
-		gboolean protected = GPOINTER_TO_INT (locks->data);
-		Sheet *sheet = workbook_sheet_by_index (wb, sheetno);
-
-		if (sheet != NULL)
-			g_object_set (sheet, "protected", protected, NULL);
-
-		sheets = sheets->next;
-		locks = locks->next;
-	}
-	return FALSE;
-	
-}
-
-/**
- * workbook_sheet_change_visibility:
- * @wb:          workbook to look for
- * @sheets   :   list of sheet indices (ignore -1)
- * @visibility:  list of new visibility
- *
- * Adjusts the visibility
- *
- * Returns FALSE when it was successful
- **/
-gboolean    
-workbook_sheet_change_visibility  (Workbook *wb,
-				   GSList *sheets,
-				   GSList *visibility)
-{
-	g_return_val_if_fail (g_slist_length (sheets) 
-			      == g_slist_length (visibility), 
-			      TRUE);
-
-	while (sheets) {
-		Sheet *sheet = workbook_sheet_by_index 
-			(wb, GPOINTER_TO_INT (sheets->data));
-		if (sheet != NULL) {
-			GnmSheetVisibility v = GPOINTER_TO_INT (visibility->data);
-			g_object_set (sheet,
-				      "visibility", v,
-				      NULL);
-		}
-		sheets = sheets->next;
-		visibility = visibility->next;
-	}
-	return FALSE;
-	
-}
-
 /**
  * workbook_find_command :
  * @wb : #Workbook
@@ -1429,56 +1242,6 @@ workbook_find_command (Workbook *wb, gboolean is_undo, gpointer cmd)
 	return 0;
 }
 
-/**
- * workbook_sheet_recolor:
- * @wb:          workbook to look for
- * @sheets   :   list of sheet indices (ignore -1)
- * @fore     :   list of new text colors
- * @back     :   list of new background colors
- *
- * Adjusts the foreground colors
- *
- * Returns FALSE when it was successful
- **/
-gboolean    
-workbook_sheet_recolor  (Workbook *wb,
-			 GSList *sheets,
-			 GSList *fore, 
-			 GSList *back)
-{
-	g_return_val_if_fail (g_slist_length (sheets) 
-			      == g_slist_length (fore), 
-			      TRUE);
-	g_return_val_if_fail (g_slist_length (sheets) 
-			      == g_slist_length (back), 
-			      TRUE);
-
-	while (sheets) {
-		Sheet *sheet = workbook_sheet_by_index 
-			(wb, GPOINTER_TO_INT (sheets->data));
-		if (sheet != NULL) {
-			GdkColor *fc = (GdkColor *) fore->data;
-			GdkColor *bc = (GdkColor *) back->data;
-			GnmColor *fore_color = fc ?
-				style_color_new (fc->red, fc->green,
-						 fc->blue) : NULL;
-			GnmColor *back_color = bc ?
-				style_color_new (bc->red, bc->green,
-						 bc->blue) : NULL;
-			g_object_set (sheet,
-				      "tab-foreground", fore_color,
-				      "tab-background", back_color,
-				      NULL);
-			style_color_unref (fore_color);
-			style_color_unref (back_color);
-		}
-		sheets = sheets->next;
-		fore = fore->next;
-		back = back->next;
-	}
-	return FALSE;
-}
-
 /**
  * workbook_sheet_reorder:
  * @wb:          workbook to look for
@@ -1491,39 +1254,18 @@ workbook_sheet_recolor  (Workbook *wb,
 gboolean
 workbook_sheet_reorder (Workbook *wb, GSList *new_order)
 {
-	GSList *this_sheet;
-	gint old_pos, new_pos = 0;
+	GSList   *ptr;
+	Sheet    *sheet;
+	unsigned  pos = 0;
 
 	g_return_val_if_fail (IS_WORKBOOK (wb), FALSE);
-
-	if (new_order == NULL)
-		return TRUE;
+	g_return_val_if_fail (g_slist_length (new_order) == wb->sheets->len, FALSE);
 
 	pre_sheet_index_change (wb);
 
-	this_sheet = new_order;
-	while (this_sheet) {
-		Sheet *sheet = this_sheet->data;
-
-		if (sheet != NULL) {
-			old_pos = sheet->index_in_wb;
-			if (new_pos != old_pos) {
-				int max_pos = MAX (old_pos, new_pos);
-				int min_pos = MIN (old_pos, new_pos);
-
-				g_ptr_array_remove_index (wb->sheets, old_pos);
-				go_ptr_array_insert (wb->sheets, sheet, new_pos);
-				for (; max_pos >= min_pos ; max_pos--) {
-					Sheet *sheet = g_ptr_array_index (wb->sheets, max_pos);
-					sheet->index_in_wb = max_pos;
-				}
-				WORKBOOK_FOREACH_CONTROL (wb, view, control,
-							  wb_control_sheet_move (control,
-										 sheet, old_pos););
-			}
-			new_pos++;
-		}
-		this_sheet = this_sheet->next;
+	for (ptr = new_order; NULL != ptr ; ptr = ptr->next, pos++) {
+		g_ptr_array_index (wb->sheets, pos) = sheet = ptr->data;
+		sheet->index_in_wb = pos;
 	}
 
 	post_sheet_index_change (wb);
@@ -1531,43 +1273,6 @@ workbook_sheet_reorder (Workbook *wb, GSList *new_order)
 	return FALSE;
 }
 
-
-/**
- * workbook_sheet_reorder_by_idx:
- * @wb:          workbook to look for
- * @new_order:   list of sheet indices in order
- *
- * Adjusts the order of the sheets.
- *
- * Returns FALSE when it was successful
- **/
-gboolean
-workbook_sheet_reorder_by_idx (Workbook *wb, GSList *new_order)
-{
-	GSList *sheets = NULL;
-	gboolean result;
-
-	g_return_val_if_fail (IS_WORKBOOK (wb), FALSE);
-
-	if (new_order == NULL)
-		return TRUE;
-
-	while (new_order) {
-		sheets = g_slist_prepend (sheets, 
-					  workbook_sheet_by_index 
-					  (wb,
-					   GPOINTER_TO_INT (new_order->data)));
-		new_order = new_order->next;
-	}
-	sheets = g_slist_reverse (sheets);
-
-	result = workbook_sheet_reorder (wb, sheets);
-
-	g_slist_free (sheets);
-
-	return result;
-}
-
 /**
  * workbook_uses_1904 :
  * @wb :
